# Welcome to Uvicore

The Full Stack Asynchronous Python Framework with the performance of FastAPI and the elegance of Laravel!

## About Uvicore

Uvicore is a fullstack async API, Web and CLI python framework.  Uvicore is built on great technologies such as:

- Blazing fast dual routing engine based on FastAPI and Starlette!
- Await all the things, even your CLI's thanks to AsyncClick!
- Powerful IoC container! Full control to your app! Override everything!
- Adapter pattens for multiple backends to caching, auth, events, databases and more.
- Robust modular and deep-merged config system across uvicore modules.
- Custom and expressive ORM built on top of SQLAlchemy Core.

Uvicore is the missing fullstack asynchronous framework for elegant and rapid python development


## Getting Started

View the Uvicore documentation to get started https://uvicore.io


## License

The Uvicore framework is open-sourced software licensed under the [MIT license](https://mreschke.com/license/mit).
